@@ -52,7 +52,7 @@ enum class MsgId
 {
   CHECKSUM,
   MAIN_PAGE,
-  MISSING_METADATA,
+  METADATA,
   EMPTY_ENTRY,
   OUTOFBOUNDS_LINK,
   EMPTY_LINKS,
