@@ -26,6 +26,8 @@
 #include <sstream>
 #include <fstream>
 #include <iostream>
+#include <iomanip>
+#include <map>
 
 #include <zlib.h>
 #include <magic.h>
@@ -195,18 +197,6 @@ std::string getFileContent(const std::string& path)
   throw(errno);
 }
 
-static bool isLocalUrl(const std::string url)
-{
-  if (url.find(":") != std::string::npos) {
-    return (!(url.find("://") != std::string::npos || url.find("//") == 0
-              || url.find("tel:") == 0
-              || url.find("geo:") == 0
-              || url.find("javascript:") == 0
-              || url.find("mailto:") == 0));
-  }
-  return true;
-}
-
 std::string extractRedirectUrlFromHtml(const GumboVector* head_children)
 {
   std::string url;
@@ -243,31 +233,18 @@ std::string extractRedirectUrlFromHtml(const GumboVector* head_children)
   return url;
 }
 
-void getLinks(GumboNode* node, std::map<std::string, bool>& links)
+std::string generateDate()
 {
-  if (node->type != GUMBO_NODE_ELEMENT) {
-    return;
-  }
-
-  GumboAttribute* attribute = NULL;
-  attribute = gumbo_get_attribute(&node->v.element.attributes, "href");
-  if (attribute == NULL) {
-    attribute = gumbo_get_attribute(&node->v.element.attributes, "src");
-  }
-  if (attribute == NULL) {
-    attribute = gumbo_get_attribute(&node->v.element.attributes, "poster");
-  }
-
-  if (attribute != NULL && isLocalUrl(attribute->value)) {
-    links[attribute->value] = true;
-  }
-
-  GumboVector* children = &node->v.element.children;
-  for (unsigned int i = 0; i < children->length; ++i) {
-    getLinks(static_cast<GumboNode*>(children->data[i]), links);
-  }
+  time_t t = time(0);
+  struct tm* now = localtime(&t);
+  std::stringstream stream;
+  stream << (now->tm_year + 1900) << '-' << std::setw(2) << std::setfill('0')
+         << (now->tm_mon + 1) << '-' << std::setw(2) << std::setfill('0')
+         << now->tm_mday;
+  return stream.str();
 }
 
+
 std::string getMimeTypeForFile(const std::string &directoryPath, const std::string& filename)
 {
   std::string mimeType;
@@ -275,9 +252,9 @@ std::string getMimeTypeForFile(const std::string &directoryPath, const std::stri
   /* Try to get the mimeType from the file extension */
   auto index_of_last_dot = filename.find_last_of(".");
   if (index_of_last_dot != std::string::npos) {
-    mimeType = filename.substr(index_of_last_dot + 1);
+    auto extension = filename.substr(index_of_last_dot + 1);
     try {
-      return extMimeTypes.at(mimeType);
+      return extMimeTypes.at(extension);
     } catch (std::out_of_range&) {}
   }
 
