@@ -33,6 +33,7 @@
 #include <queue>
 
 #include "zimcreatorfs.h"
+#include "../metadata.h"
 #include "../tools.h"
 #include "../version.h"
 #include "tools.h"
@@ -49,6 +50,7 @@ std::string scraper = "zimwriterfs-" VERSION;
 std::string name;
 std::string source;
 std::string description;
+std::string longDescription;
 std::string welcome;
 std::string illustration;
 std::string redirectsPath;
@@ -80,6 +82,52 @@ bool thereAreMissingArguments()
       || illustration.empty();
 }
 
+zim::Metadata makeMetadata() {
+  zim::Metadata metadata;
+
+  metadata.set("Language",        language);
+  metadata.set("Publisher",       publisher);
+  metadata.set("Creator",         creator);
+  metadata.set("Title",           title);
+  metadata.set("Description",     description);
+  metadata.set("LongDescription", longDescription);
+  metadata.set("Name",            name);
+  metadata.set("Source",          source);
+  metadata.set("Flavour",         flavour);
+  metadata.set("Scraper",         scraper);
+  metadata.set("Tags",            tags);
+  metadata.set("Date",            generateDate());
+  if ( !illustration.empty() )  {
+    const auto data = getFileContent(directoryPath + "/" + illustration);
+    metadata.set("Illustration_48x48@1", data);
+  }
+
+  return metadata;
+}
+
+
+bool checkMetadata(const zim::Metadata& metadata)
+{
+  const auto errors = metadata.check();
+
+  if ( !errors.empty() ) {
+    std::cerr << "Metadata doesn't meet the following requirements:\n";
+    for ( const auto& err : errors ) {
+      std::cerr << "    " << err << std::endl;
+    }
+  }
+
+  return errors.empty();
+}
+
+void addMetadata(ZimCreatorFS& zimCreator, const zim::Metadata& metadata)
+{
+  for ( const auto& kv : metadata ) {
+    zimCreator.addMetadata(kv.first, kv.second);
+  }
+}
+
+
 }
 
 // Global flags
@@ -123,6 +171,8 @@ void usage()
   std::cout << "\t-t, --title\t\ttitle of the ZIM file" << std::endl;
   std::cout << "\t-d, --description\tshort description of the content"
             << std::endl;
+  std::cout << "\t-L, --longDescription\tlong description of the content"
+            << std::endl;
   std::cout << "\t-c, --creator\t\tcreator(s) of the content" << std::endl;
   std::cout << "\t-p, --publisher\t\tcreator of the ZIM file itself"
             << std::endl;
@@ -189,6 +239,7 @@ void parse_args(int argc, char** argv)
       = {{"help", no_argument, 0, 'h'},
          {"verbose", no_argument, 0, 'v'},
          {"version", no_argument, 0, 'V'},
+         {"longDescription", required_argument, 0, 'L'},
          {"welcome", required_argument, 0, 'w'},
          {"clusterSize", required_argument, 0, 'm'},
          {"name", required_argument, 0, 'n'},
@@ -218,7 +269,7 @@ void parse_args(int argc, char** argv)
 
   do {
     c = getopt_long(
-        argc, argv, "hVvijxuw:I:t:d:c:l:p:r:e:n:m:J:UB", long_options, &option_index);
+        argc, argv, "hVvijxuw:I:t:d:c:l:p:r:e:n:m:J:UBL:", long_options, &option_index);
 
     if (c != -1) {
       switch (c) {
@@ -260,6 +311,9 @@ void parse_args(int argc, char** argv)
         case 'm':
           clusterSize = atoi(optarg);
           break;
+        case 'L':
+          longDescription = optarg;
+          break;
         case 'n':
           name = optarg;
           break;
@@ -354,7 +408,7 @@ void parse_args(int argc, char** argv)
   }
 }
 
-void create_zim()
+void create_zim(const zim::Metadata& metadata)
 {
   ZimCreatorFS zimCreator(directoryPath);
   zimCreator.configVerbose(isVerbose())
@@ -386,26 +440,12 @@ void create_zim()
 
   zimCreator.startZimCreation(zimPath);
 
-  zimCreator.addMetadata("Language", language);
-  zimCreator.addMetadata("Publisher", publisher);
-  zimCreator.addMetadata("Creator", creator);
-  zimCreator.addMetadata("Title", title);
-  zimCreator.addMetadata("Description", description);
-  zimCreator.addMetadata("Name", name);
-  zimCreator.addMetadata("Source", source);
-  zimCreator.addMetadata("Flavour", flavour);
-  zimCreator.addMetadata("Scraper", scraper);
-  zimCreator.addMetadata("Tags", tags);
-  zimCreator.addMetadata("Date", generateDate());
+  addMetadata(zimCreator, metadata);
 
   if ( !welcome.empty() )  {
     zimCreator.setMainPath(welcome);
   }
 
-  if ( !illustration.empty() )  {
-    zimCreator.addIllustration(48, getFileContent(directoryPath + "/" + illustration));
-  }
-
   /* Directory visitor */
   zimCreator.visitDirectory(directoryPath);
 
@@ -438,7 +478,14 @@ int main(int argc, char** argv)
 
   try {
     parse_args(argc, argv);
-    create_zim();
+
+    const zim::Metadata metadata = makeMetadata();
+
+    if ( !checkMetadata(metadata) ) {
+      exit(1);
+    }
+
+    create_zim(metadata);
   }
   catch(std::exception &e) {
     std::cerr << "zimwriterfs: " << e.what() << std::endl;
